package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````'14``#0````X@0````0`!30`(``'
M`"@`%@`5``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!@````8````!`````$````!````````````````````R&X`
M`,AN```%```````!``$```#`?0``P'T!`,!]`0!\`@``K!(```8```````$`
M`@```,A]``#(?0$`R'T!`/````#P````!@````0```!1Y71D````````````
M```````````````&````$````%+E=&3`?0``P'T!`,!]`0!``@``0`(```0`
M```!````+VQI8B]L9"UM=7-L+6%R;6AF+G-O+C$`$0```$\````(````"```
M``&0$``E0`2`*(`0!:"&4(2``0``"R`$C3B`$D&*!`@(3P```%````!4````
M60```%H```!A````8@```&,`````````90```&8`````````9P```&@```!K
M```````````````!KS3H:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?'94
M/)0A_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!6.^7>;OCDGQ5PSS29Z_,
M9H@'<--#1=7L,V+;[16,)<Q_J9R;X*<""FH:GE"_VE<;H^#[20``````````
M````````````````@!`````````#``<```````"``0```````P`1``$`````
M`````````!(```#F`0`````````````2````"0``````````````$0````P"
M`````````````!$```"(`0`````````````2````$```````````````$@``
M`,4!`````````````!(````8```````````````2````'P``````````````
M$@```!D"`````````````!(```#1`0`````````````2````*```````````
M````(````$T#`````````````"$```!````````````````2````1@``````
M````````$@```$T``````````````!(````:`P`````````````2````"P,`
M````````````$@```+4"`````````````!(```!4```````````````2````
M5@(`````````````$@```%L``````````````!(```#J`@`````````````2
M````8@``````````````$@```&H``````````````!(```#3`@``````````
M```2````<@``````````````$@```'L``````````````"`````$`P``````
M```````2````EP``````````````$@```)P``````````````!(````J`@``
M```````````1````\0(`````````````$@```(,"`````````````!(```"C
M```````````````2````=0(`````````````$@```)$#`````````````!(`
M``!,`P`````````````1````IP(`````````````$@```#D#````````````
M`!(````U`@`````````````2````3@,`````````````$0```*H`````````
M`````!(````Q`P`````````````2````LP``````````````$0```)8!````
M`````````!(```#%```````````````B````U```````````````(````.H`
M`````````````!(```#\`@`````````````2````DP(`````````````$@``
M`.\``````````````!(```#U```````````````@````W@(`````````````
M$@````\!`````````````!(```"V`0`````````````2````%`$`````````
M````$@```,,"`````````````!(````:`0`````````````2````I0$`````
M````````$@```"@!`````````````!(````Y`0`````````````2````40(`
M````````````$@```&("`````````````!(````_`0`````````````2````
MG`(`````````````$@```"H#`````````````!(```!.`0`````````````2
M````(@,`````````````$@```&(!`````````````!(```!,`@``````````
M```2````]`$`````````````$@```&D!`````````````!(```!P`0``````
M```````2````2P,`````````````(0```($!`````````````!(```"1!```
M;)`!```````0`!(`1@,``)T3``"``0``$@`)``8"``!Q,0```@```!(`"@#3
M`P``O1\``,@$```2``D`H00``-DF```X````$@`)`+`#``!A&P``!````!(`
M"0!%!```@1````(````2``<`]@,``(4D``!4`@``$@`)`$L$```\@`$`````
M`!``$@!Y!```91L``&P!```2``D`+@0``#R``0``````$``2`,$#``!1'P``
M;````!(`"0#@`P``"1H``$`````2``D`Z`,```$?``!`````$@`)``P$``#U
M+P``P@```!(`"0`A!```T1P``!(````2``D`.@0``&R0`0``````$``2`)P$
M``!LD`$``````!``$@!V`P``.14``$`````2``D`600``.,<``":````$@`)
M`!<$```X@`$`!````!$`$0!R!```/(`!```````0`!$`,P0``!T5````````
M$@`)`$($``"Y+P``/````!(`"0!_`P``01\``!`````2``D`F@,``)$:``#0
M````$@`)`(8$``"W,```N````!(`"0"0!```;)`!```````0`!(`900``'T=
M``"$`0``$@`)``!O<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!S;G!R
M:6YT9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P:60`<W1R
M8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N8VUP`&-L;W-E9&ER`%])
M5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!O<&5N`'-T<G-T<@!S=')C:'(`
M<F5A9&QI;FL`7U]S=&%C:U]C:&M?9W5A<F0`7U]C>&%?9FEN86QI>F4`7U]R
M96=I<W1E<E]F<F%M95]I;F9O`&5X:70`8VQO<V4`7TE435]R96=I<W1E<E1-
M0VQO;F5486)L90!R96%D`')M9&ER`%]?<W1A=%]T:6UE-C0`7U]E<G)N;U]L
M;V-A=&EO;@!M:V1I<@!?7VQS=&%T7W1I;64V-`!P=&AR96%D7V=E='-P96-I
M9FEC`&UE;6-P>0!S=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R
M;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E
M<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT
M`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?
M=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!097)L7V-R;V%K
M7VUE;6]R>5]W<F%P`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R
M:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R
M=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O
M=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E
M<FQ?86QL;V,`9G!R:6YT9@!S=')D=7``<'1H<F5A9%]A=&9O<FL`<F5A9&1I
M<@!S<')I;G1F`'-T<G1O:P!S=')N8W!Y`%]?;&EB8U]S=&%R=%]M86EN`%]?
M7V5N=FER;VX`;&EB<&5R;"YS;P!L:6)C+FUU<VPM87)M=C<N<V\N,0!?<W1A
M<G1?8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8W5R<F5N=%]E
M>&5C7W!R;V,`<&%R7V-U<G)E;G1?97AE8P!P87)?<V5T=7!?;&EB<&%T:`!P
M87)?;6MT;7!D:7(`>'-?:6YI=`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L
M<U]005)?0D]/5`!S:&%?=7!D871E`&UY7W!A<E]P;`!P87)?8F%S96YA;64`
M7U]B<W-?<W1A<G0`7U]E;F1?7P!S:&%?:6YI=`!?7V)S<U]S=&%R=%]?`'!A
M<E]D:7)N86UE`'!A<E]I;FET7V5N=@!?961A=&$`<&%R7V9I;F1P<F]G`'-H
M85]F:6YA;`!?7V)S<U]E;F1?7P!?96YD`'!A<E]C;&5A;G5P`"]U<W(O;&EB
M+W!E<FPU+V-O<F5?<&5R;"]#3U)%``#`?0$`%P```,1]`0`7````P'\!`!<`
M``#,?P$`%P```-A_`0`7`````(`!`!<````(@`$`%P````R``0`7````%(`!
M`!<````8@`$`%P```!R``0`7````((`!`!<````D@`$`%P```"R``0`7````
M,(`!`!<````X@`$`%P```,1_`0`5!0``R'\!`!4&``#0?P$`%0X``-1_`0`5
M'@``W'\!`!4B``#@?P$`%2P``.1_`0`5+P``Z'\!`!4Q``#L?P$`%3(``/!_
M`0`5-P``]'\!`!4\``#X?P$`%3X``/Q_`0`50@``Q'X!`!8#``#(?@$`%@0`
M`,Q^`0`6!P``T'X!`!8(``#4?@$`%@D``-A^`0`6"@``W'X!`!8+``#@?@$`
M%@P``.1^`0`6#0``Z'X!`!8.``#L?@$`%A```/!^`0`6$0``]'X!`!82``#X
M?@$`%A,``/Q^`0`6%````'\!`!85```$?P$`%A8```A_`0`6%P``#'\!`!88
M```0?P$`%AD``!1_`0`6&@``&'\!`!8;```<?P$`%AP``"!_`0`6'0``)'\!
M`!8?```H?P$`%B```"Q_`0`6(0``,'\!`!8C```T?P$`%B0``#A_`0`6)0``
M/'\!`!8F``!`?P$`%B<``$1_`0`6*0``2'\!`!8J``!,?P$`%BL``%!_`0`6
M+0``5'\!`!8N``!8?P$`%C```%Q_`0`6,0``8'\!`!8R``!D?P$`%C,``&A_
M`0`6-```;'\!`!8U``!P?P$`%C8``'1_`0`6.```>'\!`!8Y``!\?P$`%CH`
M`(!_`0`6.P``A'\!`!8]``"(?P$`%C\``(Q_`0`60```D'\!`!9!``"4?P$`
M%D,``)A_`0`61```G'\!`!9%``"@?P$`%D8``*1_`0`61P``J'\!`!9(``"L
M?P$`%DD``+!_`0`62@``M'\!`!9+``"X?P$`%DP``+Q_`0`63@```;6]Z`%`
M<$<$X"WE!."?Y0[@C^`(\+[E(&X!``#&C^(6RHSB(/Z\Y0#&C^(6RHSB&/Z\
MY0#&C^(6RHSB$/Z\Y0#&C^(6RHSB"/Z\Y0#&C^(6RHSB`/Z\Y0#&C^(6RHSB
M^/V\Y0#&C^(6RHSB\/V\Y0#&C^(6RHSBZ/V\Y0#&C^(6RHSBX/V\Y0#&C^(6
MRHSBV/V\Y0#&C^(6RHSBT/V\Y0#&C^(6RHSBR/V\Y0#&C^(6RHSBP/V\Y0#&
MC^(6RHSBN/V\Y0#&C^(6RHSBL/V\Y0#&C^(6RHSBJ/V\Y0#&C^(6RHSBH/V\
MY0#&C^(6RHSBF/V\Y0#&C^(6RHSBD/V\Y0#&C^(6RHSBB/V\Y0#&C^(6RHSB
M@/V\Y0#&C^(6RHSB>/V\Y0#&C^(6RHSB</V\Y0#&C^(6RHSB:/V\Y7A'_><`
MQH_B%LJ,XES]O.4`QH_B%LJ,XE3]O.4`QH_B%LJ,XDS]O.4`QH_B%LJ,XD3]
MO.4`QH_B%LJ,XCS]O.4`QH_B%LJ,XC3]O.4`QH_B%LJ,XBS]O.4`QH_B%LJ,
MXB3]O.4`QH_B%LJ,XAS]O.4`QH_B%LJ,XA3]O.4`QH_B%LJ,X@S]O.4`QH_B
M%LJ,X@3]O.4`QH_B%LJ,XOS\O.4`QH_B%LJ,XO3\O.4`QH_B%LJ,XNS\O.4`
MQH_B%LJ,XN3\O.4`QH_B%LJ,XMS\O.4`QH_B%LJ,XM3\O.4`QH_B%LJ,XLS\
MO.4`QH_B%LJ,XL3\O.4`QH_B%LJ,XKS\O.4`QH_B%LJ,XK3\O.4`QH_B%LJ,
MXJS\O.4`QH_B%LJ,XJ3\O.4`QH_B%LJ,XIS\O.4`QH_B%LJ,XI3\O.4`QH_B
M%LJ,XHS\O.5X1_WG`,:/XA;*C.*`_+SE`,:/XA;*C.)X_+SE>$?]YP#&C^(6
MRHSB;/R\Y0#&C^(6RHSB9/R\Y0#&C^(6RHSB7/R\Y0#&C^(6RHSB5/R\Y0#&
MC^(6RHSB3/R\Y0#&C^(6RHSB1/R\Y0#&C^(6RHSB//R\Y0#&C^(6RHSB-/R\
MY0#&C^(6RHSB+/R\Y0#&C^(6RHSB)/R\Y3"UB;#-Z080!9(&J06J!ZA*3/_W
M5N]*2WQ$XU@#DTE+`YKC6!%&&$8$D__WONY&2^-8'7A%2^18?;G_]P;O1$IZ
M1!!A$+D!(/_W3.__]V[O(&C_]Z;O@/A]5R!H__>@[Y#XSC-#\`(#@/C.,R!H
M__>8[Y#XSC-#\`$#@/C.,P>8!3"P\8!/`=/_]PCO@`#_]T+O`48&G"]+(FA[
M1`)@+DJ88'I$0F`M2GI$$FB"8"Q*>D1!^`PO!"):8`$C!YJ:0C;<`"$"\8!#
M`S,F34#X(Q``D25)?40#1@,R*&EY1/_WE.X$1ABY*&G_]PCO!$8?37U$*&G_
M]\;N'4AX1`#P&/E@N>MH([D;2'A$`/`1^>A@&4M[1-AH"+$!\!#Y%TM[1!AI
M__=0[__W^.T@1@FP,+U4^"-0`3-!^`1?P.<`:P$`1`$``$`!```0`0``)`$`
M`'AL`0`>;`$`Z1\``/!K`0#>'P``Y&L!`,T%``#(:P$`G1T``$0=``"F:P$`
MFFL!`$_P``M/\``.`TEY1&A&(/`/#.5&`/`"^)YH`0`?M0M+"TI[1)I8`I(*
M2II8`Y(`(@&2"4J;6`(=`),!:`*;`YC_]V;N!;!=^`3[`+]V:0$`(`$```@!
M```4`0``!D@'2P=*>$1[1(-">D0#T`5+TU@#L1A'<$<`O[IJ`0"X:@$`,&D!
M`!P!```(2`E)>$1Y1`D:RP\'2@/KH0%)$'I$`]`%2]-8`[$81W!'`+^0:@$`
MCFH!`/QH`0`X`0``#DL0M7M$#DP;>'Q$H[D-2^-8([$,2WM$&&C_]SKN__>_
M_PI+XU@;L0E(>$3_]X#M`2((2WM$&G`0O0"_7&H!`-)H`0`P`0``#FH!`!@!
M``"^6```+&H!``BU!TL'2GM$FU@KL09)!TAY1'A$__<6[KWH"$"JYP"_?F@!
M`#0!``#\:0$`?E@``!A++>GP1WM$BD8%1CBS%DJ;6!QH!+,#1AY&$_@!*SJY
MH49V&\A&6?@$>R>Y/$83X#TJ]=#PYS)&*48X1O_W?.T`*._1NUT]*^S1J.L$
M!*00RO@`0'0</$0@1KWH\(<$1OKG`+].:`$`*`$```>U#$H,2WI$TUAI1AMH
M`9-/\``#__>^_PA*!TMZ1--8&F@!FUI``=#_]T;N`[!=^`3[`+_B9P$`+`$`
M`,QG`0!SM11*%$MZ1--8!$8;:`&33_```VY&$4U]1#%&($;_]YG_2+D.2@Q+
M>D336!IH`9M:0`W0__<@[@I+`)KK6!MH`^N"`UIH0_@$*P`J^M'DYP*P<+VB
M9P$`+`$``)!G`0"`9P$`*`$``"WI\$<R2C-+>D336*BP&V@GDT_P``,%1L"Q
M`WBSL?_WA.P&1I"Q+$_?^+"`W_BPD']$^$3Y1#!&__?$[`1&>+DP1O_W_.PH
M1O_WBNTE2B%+>D336!IH)YM:0#70__?8[1,T.48@1O_WJ.P`*./0048@1O_W
MHNP`*-W0*$;_]\+M@D8@1O_WONU01`(P__>^[()&(T8J1DE&__><[6E&4$;_
M]V3M`3!01@O0!)L#]'!#L_6`3P71__>C_U!&__=J[;GG__>>[/CG*+"]Z/"'
M`+\X9P$`+`$``/L9``#X&0``^1D``/!F`0`0M19*%DMZ1*BPTUAI1@1&&V@G
MDT_P``/_]T[MR+D$FP/T<$.S]8!/`M"S]2!/!M$"(2!&__<B[+#Z@/!`"0E*
M!TMZ1--8&F@GFUI``]#_]VSM`"#SYRBP$+T`OU)F`0`L`0``%F8!`"WI\$\-
M1DE*24MZ1--8A;`;:`.33_```PMX!D8]*PB_`34H1O_W1NT"J0=&,$;_][7^
MW_@`D01&^42@L?_W.NV'0C'8`3P5^`$[!/@!/P`K^=$Y2C9+>D336!IH`YM:
M0&'0__<N[35+6?@#H-KX`+!;^"0P`"M#T3%+!/$""'M$&FA/ZH@(`"H\T$%&
M6$;_][;KRO@````HV]#:^``PF$0`(TCX!#P"E#-&&$83^`$K"K$]*OG1(4N`
M&UGX`T`"-SA$W?@(D-3X`(#_]_CK2/@I```HO=`C:`*:4_@B(!;X`1L31A%P
M`3()L3TI]]$](AIP%?@!*P/X`2\`*OG1J.<!-+7G`2)`1AI@__?8ZP&0`"B>
MT%E&J/$(`O_WUNL!F\KX`#"YYP6PO>CPC^9E`0`L`0``N&4!`)IE`0`H`0``
M$F<!`!.U"DP*2WQ$XU@8:/_WDNP(2PE)XUAY1`&3"$L!FGM$`K"]Z!!`__=W
MO`"_IF0!`"0!```\`0``B1<``&Q4```3M0Q+#$I[1)Q8(&C_]W+L__?6_R!H
M__=N[``B!TL(27M$S>D`,@=*>41Z1/_W/.L"L!"]9F0!`"0!``"^&0``4Q<`
M``\*```PM2Y)+DJM]0!=A[!Y1(I8#?4`4Q0S$F@:8$_P``+_]SCK*$H#K'I$
M`)(G2@-&0?(!`2!&>D3_]P[K0QP-T0`C(D@?27A$#?4`4D%8%#((:!%H2$`M
MT/_W3NRP]8!?`-G_W@WU@%40-2!&3_2`4BE&__>@ZP0>XMM@'/_W.NL#1@`H
MW-"H0@+2`AF50NC3JT("V2H9DT+CTT'R`0*40M_<(D881BE&__<.[``B`T8"
M5<;G&$8-]0!=![`PO1AD`0`L`0``+A<``!07``#@8P$`__>6ORWI\$\-1DU)
MK?6%74Q*>42%L`1&2TB*6`WUA5-X1`PS$F@:8$_P``+_]Y[]+R$&1B!&__<R
MZXBQ0T@A1GA$__>/_D))/DIY1`WUA5.*6`PS$6@::%%`:M#_]^+K($;_]]KK
M.TF#1GE$*$;_][#K!T8X2]_XY)#?^.2@>T3Y1/I$`Y,`+]C0.G@`*@B_3T96
ML3E&,$;_]YCJ*+DQ27E$__>6ZP=&[><X1O_WM.L`)3A$P1L0^`$M+RH8T`OQ
M`0(*1++U@%^XV@.;#?&P"*CQ!`4`DU)&.T9/](!1*$8!E/_W4.H!,+#U@%\"
MV?_>!7#?YRA&!*G_]T+KJ+E8^)`\`_1P0[/U`$\.T0$A*$;_]S+J2+D42"E&
M>$3_]R+^*$;_]Y[J!$:-YQ!)`"!Y1+?G($8-]85=!;"]Z/"/`+]"8P$`+`$`
M`&@6``!1%@``"F,!`#06```B%@``OQ4``.H6``#^%0``=Q4``'`5```#1A/X
M`2L"N7!'+RH(OQA&]^<0M01&"+$#>"NY'TAX1+WH$$#_]V*Z__<^ZP$X($2$
M0@-&'M(:>`$X+RKXT)Q"&-(:1A+X`1DO*1'1`3N<0AI&`](1>`$[+RGXT!(;
MDQRS]8!?&-@!,K+U@%\-V?_>$T;DYYQ"Z=$C>"\K`M$(2'A$S><'2'A$RN<'
M2R%&>T081O_W=NH0O0`@_.>Q%```3Q0``*H4```*8P$`,+5&2D9+>D2+L--8
M:D9%21MH"9-/\``#>40!\0H#`?$J!!5&&&A9:`@S`\6C0BI&]]$;B#Q(*X!X
M1/_WJ?P[2#M,>$3_]Z3\.DA\1'A$__>?_#E(>$3_]YO\.$AX1/_WE_PW2'A$
M__>3_#9(>$3_]X_\-4AX1/_WB_P@1O_WB/PR2'A$__>$_#%(>$3_]X#\,$AX
M1/_W7/P!1A"Q($;_]U/]+4AX1/_W4_P!1ABQ*TAX1/_W2?TJ2'A$__=)_`%&
MF+$H2'A$__<__2=))TAY1'A$__<Y_29*$4MZ1--8&F@)FUI`&-#_]Y#J(DAX
M1/_W+_P!1A"Q($AX1.3G'TD*(GE$#?$1`/_WBND`*-W1'$@-\1L!>$36YPNP
M,+TR80$`+`$``/Y0``!.%```310``(,4``!+%```3!0``$L4``!3%````!0`
M`$\4``!5%```ZQ,``$\4``!.%```31,``$P4``"H$P``8A0``-<3``!>8`$`
M*!0``,L3```E%```KQ,```BU"TM[1!MH`3,,T0E(>$3_]]S[(+$`>!"Q,#@8
MOP$@!4M[1!A@!4M[1!AH"+T`O_Q@`0`Q$P``WF`!`-A@`0`(M?_W)NK_]V;I
M`+$`:`B]][463P1&?T0X1O_WM_LA1@5&"+$#>"NY$4AX1`.PO>CP0*?D__<P
MZ;"Y($;_]_SI!D8H1O_W^.DP1`(P__?XZ`9&"$L(22)&>40`E7M$__?4Z3%&
M.$;AYP.P\+U8$P``1!,``&(2```T$P``+>GP3]_X.!3?^#@DK?4!38FP>43?
M^#!4BE@-]0%#2*Q]1!)HVF%/\``"'#,J':3Q=`,%\1`.I/%<#`9&!\J#Z`<`
MON@/`*SH#P">Z`,`I/%H`R@UC.@#`)7H!P"#Z`<`^DC[3WA$__=3^W]$!4;`
ML0-XL['_]X[_]DGR2GE$#?4!0XI8'#,1:!IH44`!T/_WG.DH1@WU`4T)L+WH
M\$__]Z^X__=O_P5&F+FD\6@(6/@$"Q"YZ$U]1`O@__<I^P`H]=`#>``K\M#_
M]YSH!48`*.W0*$;_]W+I0``!,/_W<NB!1H!&W_ATHP$]^D05^`$O`"IDT:3Q
M7`A8^`1;A;$H1O_W!OL%1@`H]M`#>``K\]#_]\;[`"COT"A&__=TZ`5&I/%T
M"D6Y6O@$B[CQ``]7T)CX`#``*TG1*$;_]T#I@D9(1O_W/.E01`#R!$I01O_W
M.NB`1L)+PTE[1`"3PDLJ1GM$>43-^`20__<0Z4_TX'%`1O_WY.@!,#31__?:
MZ`-H$2LOT+E*NDFX6`"3,FA#1@!H>43_]YSH`"6V2:E*>40-]0%#BE@<,Q%H
M&FA10'_T;J\H1@WU`4T)L+WH\(]`1E%&__?DZ`CQ`@B/YT!&__=G^P`HI]!`
M1O_W%.@%1J'G14:IYT!&!*G_][;H@49(L9Y+H4GX6#)H0T9Y1`!H__=HZ,GG
MI/6(=2MI`_1P0[/U@$_MT53X^+S_]]SH@T7GT2MIP_,(`[/UX'_AT5!&_O?*
M[P5&D4AX1/_W:OH`*'_1-V@X1O_WNN@#*()&'MF,200X>40X1/[WC.^XN;KQ
M!`\$T+I$&O@%/"\K#]%V:&ZQ,$;_]Z3H`R@(V8))!#AY1#!$_O=V[P`H"+\W
M1O_W6OZ"1@`H0/"@@`%&.$;^][CO!D8`*`#PF(!/\`()3_#_,V_P$0+-^`"0
M)Q_^]T[O!B(Y1C!&__<<Z!3X!#P`*T/1%/@#/$,K/]$4^`(\02L[T13X`3Q#
M*S?1(WA(*S318WA%*S'13_#_,V_P.0(P1LWX`)#^]RKO*2(Y1C!&_O?X[T)&
M74M=27M$S>D`<UQ+>41[1"A&__<RZ$!&__<0Z%E(*49X1/_WZ/HH1O_W*_XL
MYS=H_O=@[P%&.$;_]RW\!T8`*'_T=J]SYP`C`"(`DS!&`"/^]_KN`/!)_H%&
M3_0`0CE&,$;^]\3O`AXHW#!&I/%$!O[WLN^D\3`'248P1@#PM/ZY1M_X`+'[
M1#A&6486^`$K"O$!"O[W\N^Z\10/!_$"!_+1`",$^`@\.$LX27M$S>D`DS=+
M0D9[1'E$J><Y1DA&`/`Q_LGG,TDT2'E$>$3_]Y+Z_O>^[C%+,DE[1,WI``,Q
M2T)&*$9[1'E$_O?&[RY,+TXO3WQ$?D1_1$_TX'$H1O[WE.\!,(;1_O>*[P-H
M$2N!T?[WGNX)\0$)`)`C1D)&,48H1LWI`9?^]ZCOY>?F7@$`+`$``"1@`0#(
M$0``CEX!`'Q>`0!,$@``'Q(``+\1``"L$0``Y!````P!``"*$0``6ET!`%T1
M``#'$```6!$``#$1``!4$0``EA```"0/``#Z#@``<0\``*P0``#J#P``?`X`
M`!0/``"E#@``?A```,D/``!,#@``/@X``,D/``!@$```+>GX3X!+@4I[1)Q8
M(&C^]U3O!48@:/[W4.^5^&0P@/AE,'M(>$3_]P_Y(+$#>#$K`=%#>`NQ__=?
M_"!H_O<\[W1)"R,!(GE$_O>0[CB[(&C^]S+O<$D#(P$B>43^]X;N!48`*&/1
M(&C^]R;O:TD#(P$B>43^]WKN!48`*'S0:$AX1/_WX?@&1@`H9M`@:/[W%.\R
M1NMH&6C^]W3N;.`!)<-HW_B`D9]IW_A\H?E$V?@$,"!HJT(%\?\X"-W^]_SN
M`"-"1CE&_O<"[@9&.+E73GY$<V@!.YA%N=$!)2+@V?@(,`)H4_@EL)-H"NH#
M`[/U@&\'T=%H6$;^]];M`"CFT0$UU.<@:/[WV.XQ:`(C`"+^]^KN`4;NY_[W
MSNXY1O[W@NT!-7-H(&BK0O7<C^<@:/[WPN[K:#Y*&6AZ1/[W(N[K:!MHFVA;
M`HW5(&C^][3NZV@9:/[WQNV%Y__W5_H&1B!HEK/^]ZCNZV@R1AEH_O<*[C!&
M_O>&[B!H_O>>[@5&(&C^]YKN*TD!(GE$_O=<[2E*`49Z1"A&_O?T[2!H_O>,
M[@`C@/AE,"1()4QX1/_W2_A\1.!@@+F@:/_WO?S@8%BY($AX1/[W6.W^]W;N
M'DM[1)IHZV@2:%WG'$Q/].!Q?$3@:/[W1NX1*`K00QP!*P?9`T:A:!9(XF@)
M:'A$_O<\[;WH^(\`ORA:`0`D`0``>PT``-0.``#%#@``S0X``.T,```D6P$`
M``0@``!;`0#G#0``G`T``*<-``"X"P``'EH!`'T-````6@$`\%D!`&8-```X
MM01&__<!^__W]OH%1O_W"_QPL6RQ(WA;L09)*$9Y1/[W;NV%0@31($:]Z#A`
M__<UN#B]W0L``"WI\$_]2OY+>D33L--8`:H41AMH49-/\``#`/%<!0#Q'`-3
M^`0;";J=0D3X!!OXT4`D$48-:DMK!#)K0(UH"6AK0$M`3^KS<P$\TV/QT>E)
MT.D`YP&=`FD-1-#X",`51,)HQ&B,Z@(*"NH'"HKJ`@H"FHSJMP@*1`CJ#@@B
M1`7K_F6(Z@P(54201$_JO@H#FHKJMP0L0`I$8D2$ZK<$%$0$F@CK]6B*ZK4+
M"^H("PI$B^H*"P+KMP($Z_ADDT1/ZK@(!9J(ZK4&)D`*1%)$ANJU!A9$!IH+
MZ_1KB.JT"@KJ"PH*1`+KM0**Z@@*!NO[9I)$3^J["P>:B^JT!35`"D1"1(7J
MM`451`B:"NOV:HOJM@@(Z@H("D0"Z[0"B.H+"`7K^F601$_JN@H)FHKJM@D)
MZ@4)"D1:1(GJM@F11`J:".OU:(KJM0L+Z@@+"D0"Z[8"B^H*"PGK^&F31$_J
MN`@+FHCJM00$Z@D$"D121(3JM0041`R:"^OY:XCJN0H*Z@L*"D0"Z[4"BNH(
M"@3K^V221$_JNPL-FHOJN04E0`I$0D2%ZKD%%40.F@KK]&J+ZK0(".H*"`I$
M`NNY`HCJ"P@%Z_IED$1/ZKH*#YJ*ZK0&+D`*1%I$ANJT!A9$$)H(Z_5HBNJU
M"POJ"`L*1`+KM`*+Z@H+!NOX9I-$3^JX"!&:B.JU!#1`"D121(3JM0041!*:
M"^OV:XCJM@H*Z@L*"D0$Z_MD`NNU`D_JNPL3G8KJ"`J+ZK8)DD04F@GJ!`D-
M1`KK]&I%1`I$B^JT"(GJM@FI1`+KM@9H316:".H*"(CJ"PBP1%89%IH)Z_II
M*D1/ZKH*".OY:%Y$BNJT"P+KM`2*ZKD"@NH(`A1$%YJ+Z@D+41D8FEY$!NOX
M9BI$3^JX"`3K]F111(CJN0H"Z[D)B.JV`F)`BNH&"I%$&9I11`'K]&$J1$_J
MM`201(3JM@)*0)!$&IH)Z_%I`NL%"QN:"^NV"X3JL08(Z_EHANH)!BI$3^JY
M"11$B>JQ`H+J"`(41!R:LT0J1`OK^&L"Z[$!B>JX`H+J"P(11!V:!.O[9`+K
M!0H>FD_JNPLJ1`'K]&'*1(OJN`D"Z[@(B^JT`DI`B>H$"9!$'YK*1`KK\6I6
M&4_JL0$@FEY$@>JT"XOJ"@M>1`+K!0LAF@CK^F@+Z[0+@>JZ!`;K^&:$Z@@$
M*D1/ZK@($42(ZKH"<D`11"*:HT0J1`OK]FL"Z[H*B.JV`H+J"P*21".:`>O[
M80+K!0DDFD_JNPLJ1`KK\6K!1(OJM@@"Z[8&B^JQ`H+J"@*(Z@$(%D0EFL%$
M">OZ:5093^JZ"B::7$2*ZK$+B^H)"UQ$`NL%"PC@`+^9>8):H>O9;IQ7`0`L
M`0``!NOY9@OKL0N*ZKD!<4"+1">9!.OV9"E$3^JV!BB:BD2&ZKD!"^OT:V%`
M*D2*1$_JNP4"Z[D)ANJT`@KK^VJ"Z@L"1>JT")%$".H*"`7JM`(IF4CJ`@CK
M2@GK^FD11#%$1>JZ!HA$!NH)!@7JN@$.0RJ9".OY:!%$3^JY"0'KM`%)ZKH$
M#D0$Z@@$">JZ`0Q#*YD&Z_AF$40I1$GJN`4,1#5`">JX`0U#+)D$Z_9D$41/
MZK8&`>NZ`4;JN`L-1`OJ!`L&ZK@!2^H!"RV9!>OT91%$241&ZK0)BT0)Z@4)
M!NJT`4GJ`0DNF0OK]6L11$_JM04!Z[@!1>JT"HE$"NH+"@7JM`%*Z@$*+YD)
MZ_MI$40Q1$7JNP:*1`;J"08%ZKL!#D,PF0KK^6H11$_JN0D!Z[0!2>J["`Y$
M".H*"`GJNP%(Z@$(,9D&Z_IF$40I1$GJN@6(1#5`">JZ`0U#,IDSG!%$".OV
M:`'KNP%/ZK8&1NJZ"PU$%$0%Z_AE!NJZ`4Q$"^H("T;JN`E+Z@$+">H%"0;J
MN`%)Z@$)-)FC1`OK]6L11$_JM04!Z[H!1>JX"HE$"NH+"@7JN`%*Z@$*-9D)
MZ_MI$40Q1#:>1>J[!(I$!.H)!`7JNP$61`;KN`8,0PKK^6HT1$_JN0DWGDGJ
MNP@)ZKL!".H*"!9$+D1(Z@$(L$0XG@3K^F1)ZKH!".OT:`GJN@4A0!9$3^JT
M!"E#!NN[!D3JN@4Q1`7J"`4$ZKH&-4,YG@'K^&$61$Y$1.JX"35$">H!"03J
MN`9)Z@8).IX%Z_%E%D1/ZK$!!NNZ!D'JN`JQ1`KJ!0H!ZK@&2NH&"CN>">OU
M:19$-$1!ZK4&5$0&Z@D*`>JU!DKJ!@H\G@3K^60R1`+KN`@]GEM*3^JY"19$
M,42)ZK4&9D`Q1#Z>T$061`CK]&@&Z[4%B>JT!H;J"`8U1#^>`>OX819$3^JX
M"+%$B.JT!DY`L41`G@7K\6461`;KM`2(ZK$&;D`T1$&>">OU:19$3^JU!;!$
MA>JQ!H;J"0:P1$*>!.OY9!9$!NNQ`87JN09F0#%$0YX(Z_1H%D1/ZK0$-42$
MZKD&ANH(!C5$1)X!Z_AA%D0&Z[D)A.JX!DY`L41%G@7K\6461$_JL0$T1('J
MN`9N0#1$1IX)Z_5I%D0&Z[@(@>JU!H;J"0:P1$>>!.OY9!9$3^JY"3%$B>JU
M!F9`,41(G@CK]&@61`;KM06)ZK0&ANH(!C5$29X!Z_AA%D1/ZK@(L42(ZK0&
M3D"Q1$J>!>OQ919$!NNT!(CJL09N0#1$2YX)Z_5I%D1/ZK4%L$2%ZK$&ANH)
M!K!$3)X$Z_ED%D0&Z[$!A>JY!F9`,41-G@CK]&@61$_JM`0U1`3@`+_<O!N/
MUL%BRH3JN0:&Z@@&-41.G@'K^&$61`;KN0F$ZK@&`:M.0+%$T_@X8=/X/#$%
MZ_%E%D1/ZK$!$T0T1'-$@>JX!@GK]6EN0`/KN`B!ZK4#-$2#Z@D#!.OY9$-$
M`^OT8P-@#.NY`X-@PV@*2@/KM04#:3Q$&40(2WI$1&#%8`%ATU@::%&;6D`!
MT/[W[NE3L+WH\(\`OR)/`0`L`0``"+5@(/[WX.@*2@M)`F`"\8@R0F`"\2E"
MHO66$J+VBV*"8*+QB#+"8``BP.D$$H)APF4(O0$C16?PX=+#+>GP019&!49#
M:=(`FQ@HOX)I0V$DOP$R@F&#:07Q'`<#ZU9S@V'`;?"QP/%`!+1".$2HOS1&
MB$(#T@,9F4(`TO_>B$(!ZP0(`=E`1?C3(D;^]X;IZVTC1$`KZV47T2A&__=<
M^T%&-AL%\5P(/RX0W+E"`MF[&9E"XM.Y0@+2BQF?0MW3,D8X1O[W:NGN9;WH
M\(&Y0@'90472TX]"`?%``P'9GT+,TPQ&.D94^`0;G$)"^`0;^=$H1O_W,/M`
M/B%&U.<MZ?!!`?$<!TMICFD,1H`AD_J#^,/SQ0-:'#@J!48VNOE4!^L"`$/=
M`"'"\4`"_O<ZZ"!&__<1^S@B`"$X1O[W,N@@1L3I%6C_]P?[XW@@1BMP8XAK
M<"-H&PJK<"-HZW#C>2MQXXAK<6-H&PJK<6-HZW'C>BMR8XEK<J-H&PJK<J-H
MZW+C>RMSXXEK<^-H&PJK<^-HZW/C?"MT8XIK="-I&PJK="-IZW2]Z/!!_O?/
MN``APO$X`L+G`+\!M;WH`4!P1R]T;7``4$%27U1-4$1)4@!414U01$E2`%1-
M4`!54T52`%5315).04U%`"XN`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN
M84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E<P!E>&4`
M4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%
M4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%2
M7T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P!0
M05)?1TQ/0D%,7U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#
M3$5!3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0051(`%-94U1%30`E,#)X
M`"5S)7,E<R5S`'!A<BT`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`E<SH@<')I=F%T92!S=6)D
M:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R
M971R>2!Y;W5R(&]P97)A=&EO;BD*`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E
M<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`
M4$%2.CI086-K97(Z.E9%4E-)3TX`,2XP-3``56YA8FQE('1O(&-R96%T92!C
M86-H92!D:7)E8W1O<GD`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`M90`M+0!E=F%L
M("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@
M(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?
M<&P["FUY("@D4$%27TU!1TE#+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M
M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@
M1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A
M<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I
M(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T
M96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*
M;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A8
M6%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL
M"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP
M("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@
M+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE
M;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G
M(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF
M:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N
M=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ
M<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N
M=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N
M86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ
M0D]/5#L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*979A;"!["E]P87)?
M:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@
M)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_
M("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I
M;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^
M("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?
M<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@
M)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*
M;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(
M*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N
M:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@
M/#T@)&-H=6YK7W-I>F4I('L*)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM
M>2`D;2`]("1S:7IE("4@)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S
M(#T@)'-I>F4@+2`D;3L*?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@
M)&-H=6YK7W-I>F4["GT*=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K
M*%]&2"P@)&UA9VEC7W!O<RP@,"D["G)E860H7T9(+"`D8G5F+"`D8VAU;FM?
M<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*2D["FEF("@H;7D@)&D@/2!R:6YD
M97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D
M:3L*;&%S=#L*?0HD;6%G:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@
M:68@)&UA9VEC7W!O<R`\(#`["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@
M,#L*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M-"`M('5N<&%C:R@B3B(L("1B=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&
M2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*
M=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR
M96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M
M92`]("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N
M+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]
M*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H
M)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U
M9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H
M9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD
M+VDI('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B
M=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@
M/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE
M?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H
M;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE
M;F%M92`](%]T96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I
M.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I
M<F5?;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE
M>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M
M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C
M86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E
M='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D
M96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!O<B!R971U<FX["B1)3D-[
M)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[
M4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D
M92@D9F@I.PIP<FEN="`D9F@@)&EN9F\M/GMB=69].PIS965K*"1F:"P@,"P@
M,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP
M9FEL92@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M
M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL
M96YA;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B
M0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB
M.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE
M879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E
M($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E
M<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O
M<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O
M7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D
M9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN
M<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*
M;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z
M:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L
M("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@
M<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q
M=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?
M<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I
M*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN
M<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@
M=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E
M=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H
M:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM
M>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>
M+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G
M22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-
M)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS
M:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U
M="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E
M)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE
M;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q
M("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A
M;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A
M8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@
M)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI
M=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@
M9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN
M8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A
M<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@
M)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I
M;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E
M96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I
M;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE
M<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]4
M4E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]
M("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E
M96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`
M<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E
M86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV
M>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O
M7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N
M(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"([
M"B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G
M("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M
M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR
M97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@
M/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E
M)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*
M)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM
M>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H
M87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N
M9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS
M;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H
M(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH
M7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@
M*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ
M6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L
M94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA
M<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]
M("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F
M:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF
M("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*
M;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I
M;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*
M:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*
M96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P
M96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,
M13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH
M7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]6
M15)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L
M("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I
M*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L
M96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX
M+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D
M;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT
M*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&
M:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@
M)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D
M;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ
M4TA!+3YN97<H,2D["F]P96XH;7D@)&9H+"`B/"(L("1O=70I.PIB:6YM;V1E
M*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-A8VAE
M7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP
M(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X]
M(")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H
M+3YP<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@
M)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O
M<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q
M=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P
M97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&
M2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H
M=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<[
M"B1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV
M93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,
M:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z
M:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[
M4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN
M="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X
M="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@
M)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]
M?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I
M/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]
M>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL
M93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M
M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC
M;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?
M;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B
M*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE
M(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA
M;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D
M7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z
M("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R
M8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL
M95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]
M("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N
M86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N
M86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E
M*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ
M4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T
M:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q
M=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R
M.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V
M87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X
M<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#
M;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*
M<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!]
M.PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L
M87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U
M<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E
M('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C
M86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R
M7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX[
M"GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?
M5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%
M35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD
M("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U
M:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@
M)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S
M97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@
M)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N
M86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-
M)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P
M871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M
M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.
M?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E
M;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#([
M"G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(
M12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q
M.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*
M>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M
M/FYE=R@Q*3L*;W!E;BAM>2`D9F@L("(\(BP@)'!R;V=N86UE*3L*8FEN;6]D
M92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M
M/FAE>&1I9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG
M>U]D96QI;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@
M>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?
M9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@
M:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M
M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*
M=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL
M;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@
M(F-A;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I
M;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E
M;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F
M=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL
M;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[
M4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI
M+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H
M)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?
M5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@
M<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF
M("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O
M;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D
M<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G
M;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E
M>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#
M;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI
M<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!]
M.PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA
M;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P
M(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E
M>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M
M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@
M*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E
M9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W
M9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D
M0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N
M=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T
M=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O
M<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-
M12`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-
M4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@
M)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,
M3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!
M3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E
M;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM0
M05)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C
M;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@
M/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B
M(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT
M("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U
M8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@
M9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB
M97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A
M<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER
M92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM
M<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E
M<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T
M;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]2
M13HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]2
M13HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.
M1%]?"@!P97)L>'-I+F,`7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````Q%@``V14```$```!6`P```0```&$#```/````
MK00```P```"!$```#0```'$Q```9````P'T!`!L````$````&@```,1]`0`<
M````!````/7^_V\L`0``!0```-0(```&````%`(```H```#+!```"P```!``
M```5``````````,```"X?@$``@```/@!```4````$0```!<```"(#@``$0``
M`*`-```2````Z````!,````(````&`````````#[__]O`0``"/K__V\0````
M`````````````````````````````````````````````````````,A]`0``
M`````````(@0``"($```B!```(@0``"($```B!```(@0``"($```B!```(@0
M``"($```B!```(@0``"($```B!```(@0``"($```B!```(@0``"($```B!``
M`(@0``"($```B!```(@0``"($```B!```(@0``"($```B!```(@0``"($```
MB!```(@0``"($```B!```(@0``"($```B!```(@0``"($```B!```(@0``"(
M$```B!```(@0``"($```B!```(@0``"($```B!```(@0``"($```B!```(@0
M``"($```B!```(@0``"($```B!```(@0``"($```B!```)T3````````````
M`'$Q`````````````($0````````````````````````````````````````
M````````````@`$`_____W@Q``"C,0```````'TQ``!],@``B#$``(\R``"0
M,0```````)0Q``"9,0```````#$T``!'0T,Z("A!;'!I;F4@,3`N,BXP*2`Q
M,"XR+C``03(```!A96%B:0`!*`````4W+4$`!@H'00@!"0(*!!($$P$4`14!
M%P,8`1H"'`$>!"(!`"YS:'-T<G1A8@`N:6YT97)P`"YG;G4N:&%S:``N9'EN
M<WEM`"YD>6YS='(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I
M;FD`+G)O9&%T80`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`
M+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB
M=71E<P``````````````````````````````````````````````````````
M"P````$````"````%`$``!0!```8```````````````!`````````!,```#V
M__]O`@```"P!```L`0``Z`````,`````````!`````0````=````"P````(`
M```4`@``%`(``,`&```$`````P````0````0````)0````,````"````U`@`
M`-0(``#+!``````````````!`````````"T````)`````@```*`-``"@#0``
MZ`````,`````````!`````@````V````"0```$(```"(#@``B`X``/@!```#
M````$`````0````(````/P````$````&````@!```(`0```(````````````
M```"`````````#H````!````!@```(@0``"($```%`,`````````````!```
M``0```!%`````0````8```"<$P``G!,``-0=``````````````0`````````
M2P````$````&````<#$``'`Q```(```````````````"`````````%$````!
M`````@```'@Q``!X,0``2CT``````````````0````````!9`````0````(`
M``#$;@``Q&X```0```````````````0`````````8P````X````#````P'T!
M`,!]```$```````````````$````!````&\````/`````P```,1]`0#$?0``
M!```````````````!`````0```![````!@````,```#(?0$`R'T``/`````$
M``````````0````(````A`````$````#````N'X!`+A^``!(`0``````````
M```$````!````(D````!`````P````"``0``@```/```````````````!```
M``````"/````"`````,````\@`$`/(```#`0``````````````0`````````
ME`````$````P`````````#R````<```````````````!`````0```)T````#
M``!P``````````!8@```,P```````````````0`````````!`````P``````
>````````BX```*T```````````````$`````````
